##  6R as an Evaluation Method
The 6R classification is a useful tool for identifying the most suitable transformation path for each of your applications. It was originally designed to help organizations classify their applications for cloud migration, but we recommend it as a guidepost for your modernization decisions. It also allows you to dive deeper into your TIME results.
The Gartner® TIME Framework helps assess applications based on their functional and technical fit. You may already have existing data from past initiatives that supports this. If not, explore the framework to guide decisions on which applications to tolerate, invest, migrate, or eliminate. Learn more in [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD).
6R consists of the following six strategies:
  * Rehost: Move the application to a new infrastructure without major changes. This is commonly called “lift-and-shift”.
  * Replatform: Migrate the application to a new platform with minimal changes to its core architecture.
  * Rearchitect: Redesign or rewrite the application to improve scalability, maintainability, or performance.
  * Repurchase: Replace the application with a new solution, typically a commercial off-the-shelf (COTS) or software as a service (SaaS) product.
  * Retire: Decommission the application because it’s no longer needed or supported and will be decommissioned.
  * Retain: Keep the application as-is. It continues to serve its purpose effectively.


For more information on the 6R classification, visit [6R Framework](https://help.sap.com/docs/leanix/ea/6r?locale=en-US&state=PRODUCTION&version=CLOUD).
